﻿using Syncfusion.UI.Xaml.Charts;
using Syncfusion.Windows.Shared;
using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Input;

namespace WPF
{
    public partial class MainWindow
    {
        public MainWindow()
        {
            InitializeComponent();
        }
    }

    public class ViewModel
    {
        public DataTemplate LabelTemplate;
        private readonly Random _random = new Random();
        public ChartSeriesCollection SeriesCollection { get; set; }

        public bool IsNumerical
        {
            get { return false; }
        }

        public string XLabel
        {
            get
            {
                return "Selected cases";
            }
        }

        public string Y1Label
        {
            get
            {
                return "Cost ($/Year)";
            }
        }

        public string Y2Label
        {
            get
            {
                return "Sales (Products/Year)";
            }
        }

        public ICommand BuildPieCommand
        {
            get
            {
                return new DelegateCommand<object>(BuildSeriesCommand);
            }
        }

        private void BuildSeriesCommand(object instance)
        {
            BuildSeries();
        }

        public ViewModel()
        {
            SeriesCollection = new ChartSeriesCollection();
        }

        private void BuildSeries()
        {
            // In real application, all SfChart library reference are only in UI; viewModel does not access to SfChart elements.

            SeriesCollection.Clear();

            //Y1 Axis series (ColumnSeries)
            for (int i = 1; i <= 1; i++)
            {
                var adornment = new ChartAdornmentInfo();
                adornment.ShowLabel = true;

                var series = new ColumnSeries
                {
                    ItemsSource = BuilModel(),
                    XBindingPath = "CaseName",
                    YBindingPath = "Y",
                    Label = "Cost (ColumnSeries)",
                    AdornmentsInfo = adornment
                };

                //if (series.YAxis == null)
                //{
                //    series.YAxis = new NumericalAxis();
                //    series.YAxis.OpposedPosition = false;
                //}
                SeriesCollection.Add(series);
            }

            // Y2 Axis series (LineSeries)
            for (int i = 1; i <= 3; i++)
            {
                var adornment = new ChartAdornmentInfo();
                adornment.ShowLabel = true;

                var series = new LineSeries
                {
                    ItemsSource = BuilModel(),
                    XBindingPath = "CaseName",
                    YBindingPath = "Y",
                    Label = "Sales (LineSeries)",
                    AdornmentsInfo = adornment
                };

                ActivateY2Axis(series);

                SeriesCollection.Add(series);
            }

        }

        private void ActivateY2Axis(LineSeries lineSeries)
        {
            if (!IsY2AxisActivated())
            {
                if (lineSeries.YAxis == null)
                {
                    lineSeries.YAxis = new NumericalAxis();
                    lineSeries.YAxis.OpposedPosition = true;
                }
            }
        }

        private bool IsY2AxisActivated()
        {
            foreach (var series in SeriesCollection)
            {
                if (series is XyDataSeries && (series as XyDataSeries).YAxis != null && (series as XyDataSeries).YAxis.OpposedPosition == true)
                    return true;
            }

            return false;
        }

        #region Model

        public List<Model> BuilModel()
        {
            var modelValues = new List<Model>
            {
                RamdomModel("Case Case Case Case Case Case Case Case Case Case 1"),
                RamdomModel("Case 2"),
                RamdomModel("Case 3"),
                RamdomModel("Case 4"),
                RamdomModel("Case Case Case Case Case Case Case Case Case Case 5")
            };

            return modelValues;
        }

        private Model RamdomModel(string caseName)
        {
            var model = new Model
            {
                Y = _random.Next(100, 600), //Y1: Cost
            };

            model.CaseName = caseName;

            return model;
        }

        #endregion

    }

    public class Model
    {
        public string CaseName { get; set; }
        public double Y { get; set; }
    }
}
